@@ -1,6 +1,6 @@
 use std::collections::HashSet;
 
-use congee::ArtUsize;
+use congee::ArtRaw;
 use rand::{prelude::Distribution, thread_rng, Rng};
 use shumai::{config, ShumaiBench};
 
@@ -17,7 +17,7 @@ pub struct Scan {
 }
 
 struct TestBench {
-    index: ArtUsize,
+    index: ArtRaw<usize, usize>,
     initial_cnt: usize,
 }
 
@@ -80,8 +80,8 @@ fn main() {
 
     for c in config.iter() {
         let mut test_bench = TestBench {
-            index: ArtUsize::new(),
-            initial_cnt: 5_000_000,
+            index: ArtRaw::new(),
+            initial_cnt: 50_000_000,
         };
         let result = shumai::run(&mut test_bench, c, repeat);
         result.write_json().unwrap();
