@@ -69,7 +69,7 @@ impl Node16 {
 
     #[cfg(any(not(target_feature = "sse2"), miri))]
     fn get_child_pos_linear(&self, key: u8) -> Option<usize> {
-        for i in 0..self.base.count {
+        for i in 0..self.base.meta.count {
             if self.keys[i as usize] == Self::flip_sign(key) {
                 return Some(i as usize);
             }
@@ -186,10 +186,6 @@ impl Node for Node16 {
         self.base.meta.count == 16
     }
 
-    fn is_under_full(&self) -> bool {
-        self.base.meta.count == 3
-    }
-
     // Insert must keep keys sorted, is this necessary?
     fn insert(&mut self, key: u8, node: NodePtr) {
         let key_flipped = Self::flip_sign(key);
@@ -228,4 +224,14 @@ impl Node for Node16 {
         let pos = self.get_child_pos(key)?;
         Some(self.children[pos])
     }
+
+    #[cfg(feature = "db_extension")]
+    fn get_random_child(&self, rng: &mut impl rand::Rng) -> Option<(u8, NodePtr)> {
+        if self.base.meta.count == 0 {
+            return None;
+        }
+
+        let idx = rng.gen_range(0..self.base.meta.count);
+        Some((self.keys[idx as usize], self.children[idx as usize]))
+    }
 }
