@@ -94,10 +94,6 @@ impl Node for Node4 {
         self.base.meta.count == 4
     }
 
-    fn is_under_full(&self) -> bool {
-        false
-    }
-
     fn insert(&mut self, key: u8, node: NodePtr) {
         let mut pos: usize = 0;
 
@@ -148,4 +144,13 @@ impl Node for Node4 {
         }
         None
     }
+
+    #[cfg(feature = "db_extension")]
+    fn get_random_child(&self, rng: &mut impl rand::Rng) -> Option<(u8, NodePtr)> {
+        if self.base.meta.count == 0 {
+            return None;
+        }
+        let idx = rng.gen_range(0..self.base.meta.count);
+        Some((self.keys[idx as usize], self.children[idx as usize]))
+    }
 }
