@@ -1,29 +1,29 @@
 use crate::base_node::BaseNode;
 
-/// This no longer relevant, we can delete it
 #[derive(Clone, Copy)]
-pub(crate) struct NodePtr {
-    val: usize,
+pub(crate) union NodePtr {
+    tid: usize,
+    sub_node: *const BaseNode,
 }
 
 impl NodePtr {
     #[inline]
     pub(crate) fn from_node(ptr: *const BaseNode) -> Self {
-        Self { val: ptr as usize }
+        Self { sub_node: ptr }
     }
 
     #[inline]
     pub(crate) fn from_tid(tid: usize) -> Self {
-        Self { val: tid }
+        Self { tid }
     }
 
     #[inline]
     pub(crate) fn as_tid(&self) -> usize {
-        self.val
+        unsafe { self.tid }
     }
 
     #[inline]
     pub(crate) fn as_ptr(&self) -> *const BaseNode {
-        self.val as *const BaseNode
+        unsafe { self.sub_node }
     }
 }
